==> goes-3.4.2.tar.gz: goes-3.4.2/README.md <==
# GOES
[![Static Badge](https://img.shields.io/badge/pypi-3.4.2-jade)](https://pypi.org/project/GOES/) [![DOI](https://zenodo.org/badge/213261768.svg)](https://zenodo.org/doi/10.5281/zenodo.4556211)

Python package to download and manipulate GOES-16/17/18 data.
<br><br>

# Version
3.4.2
<br><br>
If you have already installed the GOES package, update it to the latest version.
<br><br>

# Requirements
The main packages required are:
- [numpy](https://numpy.org/)
- [s3fs](https://s3fs.readthedocs.io/en/latest/install.html)
- [pyproj](https://github.com/pyproj4/pyproj)
- [netCDF4](http://unidata.github.io/netcdf4-python/)
- [requests](https://2.python-requests.org/en/master/)

**Tip**: If you install the GOES package using pip, you don't need to worry about installing these packages because they will be installed automatically.
<br><br>

# Tutorial
Find the jupyter notebook examples for the last version [here](https://github.com/joaohenry23/GOES/blob/master/examples/index.ipynb).
<br><br>

# Installation
You can install **GOES** on Python 2 or 3 on Linux, Windows or other using the following commands.
<br><br>
**Using pip** (recommended):
```
pip install GOES

```

Check if package was installed with:

```
pip show GOES
```
<br>

If you already have the package installed, update it to the latest version with:

```
pip install --upgrade GOES
```
<br>

**Using clone**:
```
clone https://github.com/joaohenry23/GOES.git
cd GOES
python setup.py install

```
<br>

**Using python**:\
Download the **GOES-master.zip** from github and following the next commands:
```
unzip GOES-master.zip
cd GOES-master
python setup.py install

```
<br>

# Change log
All notable changes to this project will be documented in this [file](https://github.com/joaohenry23/GOES/blob/master/CHANGELOG.md).
<br><br>

# Support
If you have any questions, do not hesitate to write to:
```
joaohenry23@gmail.com

```
You can write to me in spanish, portuguese or english.
<br><br>

==> goes-3.4.4.tar.gz: goes-3.4.4/README.md <==
# GOES
[![Static Badge](https://img.shields.io/badge/pypi-3.4.4-brightgreen)](https://pypi.org/project/GOES/) [![DOI](https://zenodo.org/badge/213261768.svg)](https://doi.org/10.5281/zenodo.4556211)

Python package to download and manipulate GOES-16/17/18/19 data.
<br><br>

# Version
3.4.4
<br><br>
If you have already installed the GOES package, update it to the latest version.
<br><br>

# Requirements
The main packages required are:
- [numpy](https://numpy.org/)
- [s3fs](https://s3fs.readthedocs.io/en/latest/install.html)
- [pyproj](https://github.com/pyproj4/pyproj)
- [netCDF4](http://unidata.github.io/netcdf4-python/)
- [requests](https://2.python-requests.org/en/master/)

**Tip**: If you install the GOES package using pip, you don't need to worry about installing these packages because they will be installed automatically.
<br><br>

# Tutorial
Find the jupyter notebook examples for the last version [here](https://github.com/joaohenry23/GOES/blob/master/examples/v3.4.4/index.ipynb).
<br><br>

# Installation
You can install **GOES** on Python 2 or 3 on Linux, Windows or other using the following commands.
<br><br>
**Using pip** (recommended):
```
pip install GOES

```

Check if package was installed with:

```
pip show GOES
```
<br>

If you already have the package installed, update it to the latest version with:

```
pip install --upgrade GOES
```
<br>

**Using clone**:
```
clone https://github.com/joaohenry23/GOES.git
cd GOES
python setup.py install

```
<br>

**Using python**:\
Download the **GOES-master.zip** from github and following the next commands:
```
unzip GOES-master.zip
cd GOES-master
python setup.py install

```
<br>

# Change log
All notable changes to this project will be documented in this [file](https://github.com/joaohenry23/GOES/blob/master/CHANGELOG.md).
<br><br>

# Support
If you have any questions, do not hesitate to write to:
```
joaohenry23@gmail.com

```
You can write to me in spanish, portuguese or english.
<br><br>
